# What to Expect During the Initial Launch?

Upon the initial launch of FreeGenius AI, it will download all the essential large language models that you require and automatically configure them for you.

![first_launch](https://github.com/eliranwong/freegenius/assets/25262722/c000f589-d122-433e-b89b-1936af031356)

# Bypass Downloading Large-sized Model Files

On some low-end devices, you may prefer bypassing large file downloads, you may start specify an online backend to lanuch the app, e.g.:

> freegenius -b groq